# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/ranker/scoreboard_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/ranker/scoreboard_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/ranker/scoreboard_service.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\x84\x01\n\x15\x43reateScoreboardInput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\x12\x1b\n\x13\x61\x64\x64_default_columns\x18\x02 \x01(\x08\x12\x1f\n\x17\x64uplicate_scoreboard_id\x18\x03 \x01(\t\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\xdf\x01\n\x15UpdateScoreboardInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.ranker.UpdateScoreboardInput.Patch\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12-\n\nscoreboard\x18\x03 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"E\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x07\n\x03KEY\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x10\n\x0c\x44\x45\x46\x41ULT_SORT\x10\x03\x12\x0e\n\nHISTORICAL\x10\x04\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\".\n\x17RebuildScoreboardOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"y\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x16\n\x0escoreboard_key\x18\x02 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.ranker.Scoreboard.Extra\"I\n\x18\x44\x65scribeScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"`\n\x15LookupScoreboardInput\x12\x16\n\x0escoreboard_key\x18\x02 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.ranker.Scoreboard.Extra\"G\n\x16LookupScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\xd8\x01\n\x14ListScoreboardsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.ranker.ListScoreboardsInput.Filter\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.ranker.Scoreboard.Extra\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"P\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\x93\x01\n\x1a\x44\x65scribeScoreboardRowInput\x12\x34\n\x04mode\x18\n \x01(\x0e\x32&.eolymp.ranker.Scoreboard.FetchingMode\x12\x15\n\rpunctual_time\x18\x0b \x01(\r\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"Y\n\x1b\x44\x65scribeScoreboardRowOutput\x12*\n\x03row\x18\x01 \x01(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\x12\x0e\n\x06\x66rozen\x18\n \x01(\x08\"\xd3\x04\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32&.eolymp.ranker.Scoreboard.FetchingMode\x12\x15\n\rpunctual_time\x18\x03 \x01(\r\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.ranker.ListScoreboardRowsInput.Filter\x12\x0c\n\x04sort\x18\x32 \x01(\t\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xb4\x01\n\x10\x45xpressionColumn\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x06string\x18\n \x01(\x0b\x32\".eolymp.wellknown.ExpressionString\x12/\n\x06number\x18\x0b \x01(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12.\n\x04\x65num\x18\x0c \x01(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x1a\x84\x01\n\x06\x46ilter\x12\x31\n\tmember_id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12G\n\x06\x63olumn\x18\x02 \x03(\x0b\x32\x37.eolymp.ranker.ListScoreboardRowsInput.ExpressionColumn\"g\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\x12\x0e\n\x06\x66rozen\x18\n \x01(\x08\"c\n\x18\x41\x64\x64ScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\".\n\x19\x41\x64\x64ScoreboardColumnOutput\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\"\xb4\x02\n\x1bUpdateScoreboardColumnInput\x12?\n\x05patch\x18\x01 \x03(\x0e\x32\x30.eolymp.ranker.UpdateScoreboardColumnInput.Patch\x12\x15\n\rscoreboard_id\x18\x02 \x01(\t\x12\x11\n\tcolumn_id\x18\x03 \x01(\t\x12\x30\n\x06\x63olumn\x18\x04 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"x\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\r\n\tPARENT_ID\x10\x01\x12\x07\n\x03KEY\x10\x02\x12\x08\n\x04NAME\x10\x03\x12\x0e\n\nSHORT_NAME\x10\x04\x12\t\n\x05INDEX\x10\x05\x12\x0b\n\x07VISIBLE\x10\x06\x12\x0e\n\nFILTERABLE\x10\x07\x12\x0c\n\x08SORTABLE\x10\x08\"\x1e\n\x1cUpdateScoreboardColumnOutput\"G\n\x1b\x44\x65leteScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"\x1e\n\x1c\x44\x65leteScoreboardColumnOutput\"I\n\x1d\x44\x65scribeScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tcolumn_id\x18\x02 \x01(\t\"R\n\x1e\x44\x65scribeScoreboardColumnOutput\x12\x30\n\x06\x63olumn\x18\x01 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"3\n\x1aListScoreboardColumnsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x1bListScoreboardColumnsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Column2\xb0\x15\n\x11ScoreboardService\x12\xa3\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x0e\"\x0c/scoreboards\x12\xb3\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/scoreboards/{scoreboard_id}\x12\xbe\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/rebuild\x12\xb3\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x1e*\x1c/scoreboards/{scoreboard_id}\x12\xb8\x01\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/scoreboards/{scoreboard_id}\x12\xa9\x01\n\x10LookupScoreboard\x12$.eolymp.ranker.LookupScoreboardInput\x1a%.eolymp.ranker.LookupScoreboardOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x15\"\x13/scoreboards:lookup\x12\x9f\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/scoreboards\x12\xd2\x01\n\x15\x44\x65scribeScoreboardRow\x12).eolymp.ranker.DescribeScoreboardRowInput\x1a*.eolymp.ranker.DescribeScoreboardRowOutput\"b\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02/\x12-/scoreboards/{scoreboard_id}/rows/{member_id}\x12\xbd\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02#\x12!/scoreboards/{scoreboard_id}/rows\x12\xc4\x01\n\x13\x41\x64\x64ScoreboardColumn\x12\'.eolymp.ranker.AddScoreboardColumnInput\x1a(.eolymp.ranker.AddScoreboardColumnOutput\"Z\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02&\"$/scoreboards/{scoreboard_id}/columns\x12\xd9\x01\n\x16UpdateScoreboardColumn\x12*.eolymp.ranker.UpdateScoreboardColumnInput\x1a+.eolymp.ranker.UpdateScoreboardColumnOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x32\x1a\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xd9\x01\n\x16\x44\x65leteScoreboardColumn\x12*.eolymp.ranker.DeleteScoreboardColumnInput\x1a+.eolymp.ranker.DeleteScoreboardColumnOutput\"f\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\x82\xd3\xe4\x93\x02\x32*0/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xde\x01\n\x18\x44\x65scribeScoreboardColumn\x12,.eolymp.ranker.DescribeScoreboardColumnInput\x1a-.eolymp.ranker.DescribeScoreboardColumnOutput\"e\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02\x32\x12\x30/scoreboards/{scoreboard_id}/columns/{column_id}\x12\xc9\x01\n\x15ListScoreboardColumns\x12).eolymp.ranker.ListScoreboardColumnsInput\x1a*.eolymp.ranker.ListScoreboardColumnsOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\x82\xd3\xe4\x93\x02&\x12$/scoreboards/{scoreboard_id}/columnsB/Z-github.com/eolymp/go-sdk/eolymp/ranker;rankerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ranker.scoreboard_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/ranker;ranker'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['CreateScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['CreateScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\016\"\014/scoreboards'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['UpdateScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['UpdateScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\036\032\034/scoreboards/{scoreboard_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['RebuildScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['RebuildScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/rebuild'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DeleteScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DeleteScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002\036*\034/scoreboards/{scoreboard_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\036\022\034/scoreboards/{scoreboard_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['LookupScoreboard']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['LookupScoreboard']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\025\"\023/scoreboards:lookup'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboards']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboards']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002\016\022\014/scoreboards'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboardRow']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboardRow']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002/\022-/scoreboards/{scoreboard_id}/rows/{member_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboardRows']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboardRows']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002#\022!/scoreboards/{scoreboard_id}/rows'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['AddScoreboardColumn']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['AddScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\002&\"$/scoreboards/{scoreboard_id}/columns'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['UpdateScoreboardColumn']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['UpdateScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0022\0320/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DeleteScoreboardColumn']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DeleteScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\033\212\343\n\027ranker:scoreboard:write\202\323\344\223\0022*0/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboardColumn']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['DescribeScoreboardColumn']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\0022\0220/scoreboards/{scoreboard_id}/columns/{column_id}'
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboardColumns']._loaded_options = None
  _globals['_SCOREBOARDSERVICE'].methods_by_name['ListScoreboardColumns']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\343\n\032\212\343\n\026ranker:scoreboard:read\202\323\344\223\002&\022$/scoreboards/{scoreboard_id}/columns'
  _globals['_CREATESCOREBOARDINPUT']._serialized_start=258
  _globals['_CREATESCOREBOARDINPUT']._serialized_end=390
  _globals['_CREATESCOREBOARDOUTPUT']._serialized_start=392
  _globals['_CREATESCOREBOARDOUTPUT']._serialized_end=439
  _globals['_UPDATESCOREBOARDINPUT']._serialized_start=442
  _globals['_UPDATESCOREBOARDINPUT']._serialized_end=665
  _globals['_UPDATESCOREBOARDINPUT_PATCH']._serialized_start=596
  _globals['_UPDATESCOREBOARDINPUT_PATCH']._serialized_end=665
  _globals['_UPDATESCOREBOARDOUTPUT']._serialized_start=667
  _globals['_UPDATESCOREBOARDOUTPUT']._serialized_end=691
  _globals['_REBUILDSCOREBOARDINPUT']._serialized_start=693
  _globals['_REBUILDSCOREBOARDINPUT']._serialized_end=740
  _globals['_REBUILDSCOREBOARDOUTPUT']._serialized_start=742
  _globals['_REBUILDSCOREBOARDOUTPUT']._serialized_end=788
  _globals['_DELETESCOREBOARDINPUT']._serialized_start=790
  _globals['_DELETESCOREBOARDINPUT']._serialized_end=836
  _globals['_DELETESCOREBOARDOUTPUT']._serialized_start=838
  _globals['_DELETESCOREBOARDOUTPUT']._serialized_end=862
  _globals['_DESCRIBESCOREBOARDINPUT']._serialized_start=864
  _globals['_DESCRIBESCOREBOARDINPUT']._serialized_end=985
  _globals['_DESCRIBESCOREBOARDOUTPUT']._serialized_start=987
  _globals['_DESCRIBESCOREBOARDOUTPUT']._serialized_end=1060
  _globals['_LOOKUPSCOREBOARDINPUT']._serialized_start=1062
  _globals['_LOOKUPSCOREBOARDINPUT']._serialized_end=1158
  _globals['_LOOKUPSCOREBOARDOUTPUT']._serialized_start=1160
  _globals['_LOOKUPSCOREBOARDOUTPUT']._serialized_end=1231
  _globals['_LISTSCOREBOARDSINPUT']._serialized_start=1234
  _globals['_LISTSCOREBOARDSINPUT']._serialized_end=1450
  _globals['_LISTSCOREBOARDSINPUT_FILTER']._serialized_start=1398
  _globals['_LISTSCOREBOARDSINPUT_FILTER']._serialized_end=1450
  _globals['_LISTSCOREBOARDSOUTPUT']._serialized_start=1452
  _globals['_LISTSCOREBOARDSOUTPUT']._serialized_end=1532
  _globals['_DESCRIBESCOREBOARDROWINPUT']._serialized_start=1535
  _globals['_DESCRIBESCOREBOARDROWINPUT']._serialized_end=1682
  _globals['_DESCRIBESCOREBOARDROWOUTPUT']._serialized_start=1684
  _globals['_DESCRIBESCOREBOARDROWOUTPUT']._serialized_end=1773
  _globals['_LISTSCOREBOARDROWSINPUT']._serialized_start=1776
  _globals['_LISTSCOREBOARDROWSINPUT']._serialized_end=2371
  _globals['_LISTSCOREBOARDROWSINPUT_EXPRESSIONCOLUMN']._serialized_start=2056
  _globals['_LISTSCOREBOARDROWSINPUT_EXPRESSIONCOLUMN']._serialized_end=2236
  _globals['_LISTSCOREBOARDROWSINPUT_FILTER']._serialized_start=2239
  _globals['_LISTSCOREBOARDROWSINPUT_FILTER']._serialized_end=2371
  _globals['_LISTSCOREBOARDROWSOUTPUT']._serialized_start=2373
  _globals['_LISTSCOREBOARDROWSOUTPUT']._serialized_end=2476
  _globals['_ADDSCOREBOARDCOLUMNINPUT']._serialized_start=2478
  _globals['_ADDSCOREBOARDCOLUMNINPUT']._serialized_end=2577
  _globals['_ADDSCOREBOARDCOLUMNOUTPUT']._serialized_start=2579
  _globals['_ADDSCOREBOARDCOLUMNOUTPUT']._serialized_end=2625
  _globals['_UPDATESCOREBOARDCOLUMNINPUT']._serialized_start=2628
  _globals['_UPDATESCOREBOARDCOLUMNINPUT']._serialized_end=2936
  _globals['_UPDATESCOREBOARDCOLUMNINPUT_PATCH']._serialized_start=2816
  _globals['_UPDATESCOREBOARDCOLUMNINPUT_PATCH']._serialized_end=2936
  _globals['_UPDATESCOREBOARDCOLUMNOUTPUT']._serialized_start=2938
  _globals['_UPDATESCOREBOARDCOLUMNOUTPUT']._serialized_end=2968
  _globals['_DELETESCOREBOARDCOLUMNINPUT']._serialized_start=2970
  _globals['_DELETESCOREBOARDCOLUMNINPUT']._serialized_end=3041
  _globals['_DELETESCOREBOARDCOLUMNOUTPUT']._serialized_start=3043
  _globals['_DELETESCOREBOARDCOLUMNOUTPUT']._serialized_end=3073
  _globals['_DESCRIBESCOREBOARDCOLUMNINPUT']._serialized_start=3075
  _globals['_DESCRIBESCOREBOARDCOLUMNINPUT']._serialized_end=3148
  _globals['_DESCRIBESCOREBOARDCOLUMNOUTPUT']._serialized_start=3150
  _globals['_DESCRIBESCOREBOARDCOLUMNOUTPUT']._serialized_end=3232
  _globals['_LISTSCOREBOARDCOLUMNSINPUT']._serialized_start=3234
  _globals['_LISTSCOREBOARDCOLUMNSINPUT']._serialized_end=3285
  _globals['_LISTSCOREBOARDCOLUMNSOUTPUT']._serialized_start=3287
  _globals['_LISTSCOREBOARDCOLUMNSOUTPUT']._serialized_end=3380
  _globals['_SCOREBOARDSERVICE']._serialized_start=3383
  _globals['_SCOREBOARDSERVICE']._serialized_end=6119
# @@protoc_insertion_point(module_scope)
