# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/configuration_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'eolymp/judge/configuration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import contest_certification_pb2 as eolymp_dot_judge_dot_contest__certification__pb2
from eolymp.judge import contest_environment_pb2 as eolymp_dot_judge_dot_contest__environment__pb2
from eolymp.judge import contest_taxonomy_pb2 as eolymp_dot_judge_dot_contest__taxonomy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/judge/configuration_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a(eolymp/judge/contest_certification.proto\x1a&eolymp/judge/contest_environment.proto\x1a#eolymp/judge/contest_taxonomy.proto\".\n\x18\x44\x65scribeEnvironmentInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"K\n\x19\x44\x65scribeEnvironmentOutput\x12.\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Environment\"_\n\x19\x43onfigureEnvironmentInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12.\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x19.eolymp.judge.Environment\"\x1c\n\x1a\x43onfigureEnvironmentOutput\"0\n\x1a\x44\x65scribeCertificationInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"Q\n\x1b\x44\x65scribeCertificationOutput\x12\x32\n\rcertification\x18\x02 \x01(\x0b\x32\x1b.eolymp.judge.Certification\"e\n\x1b\x43onfigureCertificationInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x32\n\rcertification\x18\x02 \x01(\x0b\x32\x1b.eolymp.judge.Certification\"\x1e\n\x1c\x43onfigureCertificationOutput\"+\n\x15\x44\x65scribeTaxonomyInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\"B\n\x16\x44\x65scribeTaxonomyOutput\x12(\n\x08taxonomy\x18\x02 \x01(\x0b\x32\x16.eolymp.judge.Taxonomy\"V\n\x16\x43onfigureTaxonomyInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12(\n\x08taxonomy\x18\x02 \x01(\x0b\x32\x16.eolymp.judge.Taxonomy\"\x19\n\x17\x43onfigureTaxonomyOutput2\x91\t\n\x14\x43onfigurationService\x12\xbc\x01\n\x13\x44\x65scribeEnvironment\x12&.eolymp.judge.DescribeEnvironmentInput\x1a\'.eolymp.judge.DescribeEnvironmentOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02$\"\"/contests/{contest_id}/environment\x12\xbf\x01\n\x14\x43onfigureEnvironment\x12\'.eolymp.judge.ConfigureEnvironmentInput\x1a(.eolymp.judge.ConfigureEnvironmentOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02$\"\"/contests/{contest_id}/environment\x12\xc4\x01\n\x15\x44\x65scribeCertification\x12(.eolymp.judge.DescribeCertificationInput\x1a).eolymp.judge.DescribeCertificationOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02&\"$/contests/{contest_id}/certification\x12\xc7\x01\n\x16\x43onfigureCertification\x12).eolymp.judge.ConfigureCertificationInput\x1a*.eolymp.judge.ConfigureCertificationOutput\"V\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02&\"$/contests/{contest_id}/certification\x12\xb0\x01\n\x10\x44\x65scribeTaxonomy\x12#.eolymp.judge.DescribeTaxonomyInput\x1a$.eolymp.judge.DescribeTaxonomyOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02!\"\x1f/contests/{contest_id}/taxonomy\x12\xb3\x01\n\x11\x43onfigureTaxonomy\x12$.eolymp.judge.ConfigureTaxonomyInput\x1a%.eolymp.judge.ConfigureTaxonomyOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\x82\xd3\xe4\x93\x02!\"\x1f/contests/{contest_id}/taxonomyB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.configuration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeEnvironment']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeEnvironment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002$\"\"/contests/{contest_id}/environment'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureEnvironment']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureEnvironment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002$\"\"/contests/{contest_id}/environment'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeCertification']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeCertification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002&\"$/contests/{contest_id}/certification'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureCertification']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureCertification']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002&\"$/contests/{contest_id}/certification'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeTaxonomy']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeTaxonomy']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002!\"\037/contests/{contest_id}/taxonomy'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureTaxonomy']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['ConfigureTaxonomy']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023judge:contest:write\202\323\344\223\002!\"\037/contests/{contest_id}/taxonomy'
  _globals['_DESCRIBEENVIRONMENTINPUT']._serialized_start=276
  _globals['_DESCRIBEENVIRONMENTINPUT']._serialized_end=322
  _globals['_DESCRIBEENVIRONMENTOUTPUT']._serialized_start=324
  _globals['_DESCRIBEENVIRONMENTOUTPUT']._serialized_end=399
  _globals['_CONFIGUREENVIRONMENTINPUT']._serialized_start=401
  _globals['_CONFIGUREENVIRONMENTINPUT']._serialized_end=496
  _globals['_CONFIGUREENVIRONMENTOUTPUT']._serialized_start=498
  _globals['_CONFIGUREENVIRONMENTOUTPUT']._serialized_end=526
  _globals['_DESCRIBECERTIFICATIONINPUT']._serialized_start=528
  _globals['_DESCRIBECERTIFICATIONINPUT']._serialized_end=576
  _globals['_DESCRIBECERTIFICATIONOUTPUT']._serialized_start=578
  _globals['_DESCRIBECERTIFICATIONOUTPUT']._serialized_end=659
  _globals['_CONFIGURECERTIFICATIONINPUT']._serialized_start=661
  _globals['_CONFIGURECERTIFICATIONINPUT']._serialized_end=762
  _globals['_CONFIGURECERTIFICATIONOUTPUT']._serialized_start=764
  _globals['_CONFIGURECERTIFICATIONOUTPUT']._serialized_end=794
  _globals['_DESCRIBETAXONOMYINPUT']._serialized_start=796
  _globals['_DESCRIBETAXONOMYINPUT']._serialized_end=839
  _globals['_DESCRIBETAXONOMYOUTPUT']._serialized_start=841
  _globals['_DESCRIBETAXONOMYOUTPUT']._serialized_end=907
  _globals['_CONFIGURETAXONOMYINPUT']._serialized_start=909
  _globals['_CONFIGURETAXONOMYINPUT']._serialized_end=995
  _globals['_CONFIGURETAXONOMYOUTPUT']._serialized_start=997
  _globals['_CONFIGURETAXONOMYOUTPUT']._serialized_end=1022
  _globals['_CONFIGURATIONSERVICE']._serialized_start=1025
  _globals['_CONFIGURATIONSERVICE']._serialized_end=2194
# @@protoc_insertion_point(module_scope)
